//
//  NSColor-NisusAdditions.h
//  WriterMerged
//
//  Created by Martin on 2007.07.19.
//  Copyright 2007 Nisus Software, Inc. All rights reserved.
//

#import <Cocoa/Cocoa.h>


// This macro allows one-line color declarations that use a system color if available, otherwise fallback to hardcoded color
#define NISUS_SYSTEM_COLOR_FALLBACK( minSystemVersion, systemColorExpr, fallbackColorExpr )	\
	({																\
		NSColor* nisusColor;										\
		if( @available(macos minSystemVersion, *) ) {				\
			nisusColor = (systemColorExpr);							\
		}															\
		else {														\
			nisusColor = (fallbackColorExpr);						\
		}															\
		nisusColor;													\
	})



@interface NSColor (NisusAdditions)

+ (NSColor*) randomColor ;
+ (NSColor*) colorWithInt256Red:(NSUInteger)red green:(NSUInteger)green blue:(NSUInteger)blue alpha:(CGFloat)alpha ;
+ (NSColor*) colorNamedNisus:(NSString*)name fallback:(NSColor*)fallback ;

- (NSColor*) inverseCalibratedRBGColor ;
- (BOOL) isColorConsideredDarkAndNotLight ;

- (BOOL) isEqualInColorSpaceName:(NSString*)name toRed:(CGFloat)r green:(CGFloat)g blue:(CGFloat)b alpha:(CGFloat)a ;
- (BOOL) isEqualToCalibratedRed:(CGFloat)r green:(CGFloat)g blue:(CGFloat)b alpha:(CGFloat)a ;
- (BOOL) isEqualToDeviceRed:(CGFloat)r green:(CGFloat)g blue:(CGFloat)b alpha:(CGFloat)a ;

- (BOOL) isEqualInColorSpaceName:(NSString*)name toColor:(NSColor*)other ;
- (BOOL) isEqualCalibratedColor:(NSColor*)c ;
- (BOOL) isEqualDeviceColor:(NSColor*)c ;

- (CGFloat) normalizedDistanceFromRGBColor:(NSColor*)other ;
- (BOOL) isEquivalentColor:(NSColor*)c ;

@end
